module.exports = defineTest({
	description: 'statements that modify definitions within unused functions are excluded'
});
